# -*- coding: utf-8 -*-

from __future__ import unicode_literals

import datetime

from driverng import MessageV2, Worklist


class Driver(MessageV2):
    SPEC = {"code": "sqavision", "label": "SQA-VISION"}

    FIELDS = [
        "SN#",
        "FIC",
        "VOL",
        "NLMORPH",
        "CONC",
        "NPMOT",
        "NPMOT5",
        "PMOT",
        "OPT1",
        "PVMOT",
        "MOT",
        "IMMOT",
        "IVOL",
        "MOT",
        "MORPHINDEX",
        "LIQ",
        "OPT2",
        "PEROX",
        "WBCCONC",
        "CTY",
        "EXD",
        "TAR",
        "RAN",
        "CTSC",
        "RST",
        "COA",
        "CMSC",
    ]

    def parse(self, data):
        if data[0] == "O":
            dict_resu = dict(
                (resu[0], resu[1])
                for resu in [test.split("^") for test in data[2:].split("|")]
            )
            return dict_resu

    def decode_message(self, message):
        worklist = Worklist(context="result")
        if message.get("SID"):
            sample = worklist.get_or_create(
                sample_id=message.get("SID"), type="patient"
            )
            date = None
            if message.get("ADT") and message.get("ATM"):
                str_date = "{}{}".format(message.get("ADT"), message.get("ATM"))
                date = datetime.datetime.strptime(str_date, "%m/%d/%y%H:%M")
            for field in self.FIELDS:
                if field in message.keys():
                    sample.results.add(
                        code=field,
                        value=message.get(field),
                        date=date if date else datetime.datetime.now(),
                    )
        elif message.get("LOT"):
            sample = worklist.get_or_create(
                sample_id=message.get("LOT"),
                control_lot=message.get("LOT"),
                type="control",
            )
            date = None
            if message.get("ADT") and message.get("ATM"):
                str_date = "{}{}".format(message.get("ADT"), message.get("ATM"))
                date = datetime.datetime.strptime(str_date, "%m/%d/%y%H:%M")
            for field in self.FIELDS:
                if field in message.keys():
                    sample.results.add(
                        code=field,
                        value=message.get(field),
                        date=date if date else datetime.datetime.now(),
                    )
        return worklist
